"""
************************************************************
meta.py - implementation detail meta information
************************************************************

Project: HALCON/Python

Description:
Information that gets generated by the build system.
Separate file to avoid slow iteration test cycle on changes to 'main' sources.

************************************************************

(c) 1996-2020 by MVTec Software GmbH

Software by: MVTec Software GmbH, www.mvtec.com
"""

__all__ = [
    'halcon_native_lib_names',
    'hdevengine_native_lib_names',
]

halcon_native_lib_names = {
    'linux': 'libhalcon.so.20.11.1',
    'darwin': 'HALCON.framework/Versions/20.11/HALCON',
    'win': 'halcon.dll',
}

hdevengine_native_lib_names = {
    'linux': 'libhdevenginecpp.so.20.11.1',
    'darwin': 'HDevEngineCpp.framework/Versions/'
    '20.11/HDevEngineCpp',
    'win': 'hdevenginecpp.dll',
}



"""
************************************************************
__init__.py - module entry point
************************************************************

Project: HALCON/Python

************************************************************

(c) 1996-2020 by MVTec Software GmbH

Software by: MVTec Software GmbH, www.mvtec.com
"""

# Make everything from operator_set visible when importing halcon.
from .operator_set import *

from .hobject import HObject
from .hhandle import HHandle
from .ffi import HError, HOperatorError, HTupleConversionError
from .interop import HInteropError
from .hdevengine import (
    HDevEngineError,
    HDevEngine,
    HDevProcedure,
    HDevProcedureCall,
    HDevProgram,
    HDevProgramCall,
)


# Import all interop to facilitate ha.* style namespace resolution,
# in an ergonomic, consistent and readable way.
from .python_interop import *
from .numpy_interop import *
